<?php
/**
 * index.php用コンテナクラス
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2007 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: admin_menuWidgetContainer.php 151 2007-12-21 01:27:10Z fishbone $
 * @link       http://www.magic3.org
 */
require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
require_once($gEnvManager->getCurrentWidgetDbPath() . '/admin_menuDb.php');

class admin_menuWidgetContainer extends BaseWidgetContainer
{
	var $db;	// DB接続オブジェクト

	/**
	 * コンストラクタ
	 */
	function __construct()
	{
		// 親クラスを呼び出す
		parent::__construct();
		
		// DBオブジェクト作成
		$this->db = new admin_menuDB();
	}
	/**
	 * テンプレートファイルを設定
	 *
	 * _assign()でデータを埋め込むテンプレートファイルのファイル名を返す。
	 * 読み込むディレクトリは、「自ウィジェットディレクトリ/include/template」に固定。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。そのまま_assign()に渡る
	 * @return string 						テンプレートファイル名。テンプレートライブラリを使用しない場合は空文字列「''」を返す。
	 */
	function _setTemplate($request, &$param)
	{	
		return 'index.tmpl.html';
	}
	/**
	 * テンプレートにデータ埋め込む
	 *
	 * _setTemplate()で指定したテンプレートファイルにデータを埋め込む。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。_setTemplate()と共有。
	 * @return								なし
	 */
	function _assign($request, &$param)
	{
		global $gEnvManager;
		global $gPageManager;
		
		// システム制御画面のときはメニューを作成しないで終了
		if ($gPageManager->getSystemHandleMode() > 0){
			return;
		}
		
		// システム管理者権限があるユーザのときは表示
		if ($gEnvManager->isSystemAdmin()){	// システム管理者の場合
			$menu = $request->trimValueOf('menu');
			
			// タスクを取得
			$task = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_TASK);
			$selectedItemId = 0;			// 選択中の項目ID
			$selectedParemtItemId = 0;		// 選択中の項目の親項目ID
			if (!empty($task) && $this->db->getNavItemsByTask('admin_menu', $task, $row)){
				$selectedItemId = $row['ni_id'];
				$selectedParemtItemId = $row['ni_parent_id'];
			}
			
			// メニューを作成
			$menuInner = '';
			$subItemId = 'sb';
			// トップレベル項目を取得
			if ($this->db->getNavItems('admin_menu', 0, $rows)){
				$topMenuCount = count($rows);
				for ($i = 0; $i < $topMenuCount; $i++){
					$isSelected = false;		// 現在選択中の項目かどうか
					$topId = $rows[$i]['ni_id'];
					
					// サブレベル取得
					$this->db->getNavItems('admin_menu', $topId, $subRows);
					// 初期表示画面
					if (count($subRows) > 0) $firstTask = '?task=' . $subRows[0]['ni_task_id'];
					
					// 「li」タグ
					$menuInner .= '<li ';
					// 選択中の項目の場合はidを追加
					if ($selectedParemtItemId == 0){		// 指定なしの場合
						if ($i == 0){
							$menuInner .= 'id="high" ';
							$isSelected = true;
						}
					} else {
						if ($selectedParemtItemId == $rows[$i]['ni_id']){
							$menuInner .= 'id="high" ';
							$isSelected = true;
						}
					}
					if ($i == 0) $menuInner .= 'class="begin" ';
					$menuInner .= 'onclick="select_menu(this), ';
					
					for ($j = 0; $j < $i; $j++){
						$menuInner .= 'go_back_menu(\'';
						$menuInner .= $subItemId . ($j + 1) . '\'), ';
					}
					$menuInner .= 'go_top_menu(\'';
					$menuInner .= $subItemId . ($i + 1) . '\'), ';
					for ($k = $i + 1; $k < $topMenuCount; $k++){
						$menuInner .= 'go_back_menu(\'';
						$menuInner .= $subItemId . ($k + 1) . '\'), ';
					}
					$menuInner = rtrim($menuInner, ', ');	// 行末の「, 」を除く
					$menuInner .= ';">' . M3_NL;
					
					// 「a」タグ
					$menuInner .= str_repeat(' ', 4);
					//$menuInner .= '<a class="top" href="' . $firstTask . '" onclick="return false;">' . $this->convertToDispString($rows[$i]['ni_name']) . '</a>' . M3_NL;
					$menuInner .= '<a class="top" href="' . $firstTask . '" >' . $this->convertToDispString($rows[$i]['ni_name']) . '</a>' . M3_NL;
					
					// 「ul」タグ
					$menuInner .= str_repeat(' ', 4);
					if ($isSelected){		// 選択中項目のとき
						$menuInner .= '<ul id="' . $subItemId . ($i + 1) . '" style="display:inline">' . M3_NL;
					} else {
						$menuInner .= '<ul id="' . $subItemId . ($i + 1) . '">' . M3_NL;
					}
					
					// 「li」タグ
					if (count($subRows) > 0){
						for ($l = 0; $l < count($subRows); $l++){
							$menuInner .= str_repeat(' ', 8);
							$menuInner .= '<li ';
							
							$subItemClass = '';
							if ($l == 0) $subItemClass .= 'begin ';
							if ($selectedItemId != 0 && $selectedItemId == $subRows[$l]['ni_id']) $subItemClass .= 'select';
							if (!empty($subItemClass)) $menuInner .= 'class="' . $subItemClass . '"';
							$menuInner .= '><a href="';
							$menuInner .= '?task=' . $subRows[$l]['ni_task_id'];	// 起動タスクパラメータを設定
							$menuInner .= '" >' . $this->convertToDispString($subRows[$l]['ni_name']) . '</a></li>' . M3_NL;
						}
					}
					$menuInner .= str_repeat(' ', 4);
					$menuInner .= '</ul>' . M3_NL;
					$menuInner .= '</li>' . M3_NL;
				}
			}
			$this->tmpl->addVar("menu", "menu_inner", $menuInner);
			
			// メニューを表示
			if ($menu != 'off'){		// メニュー表示のとき
				$this->tmpl->setAttribute('menu', 'visibility', 'visible');
			}
		}
	}
}
?>
