<?php
/**
 * index.php用コンテナクラス
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2009 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: default_mainmenuWidgetContainer.php 1945 2009-05-31 05:01:34Z fishbone $
 * @link       http://www.magic3.org
 */
require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
require_once($gEnvManager->getCurrentWidgetDbPath() . '/default_mainmenuDb.php');

class default_mainmenuWidgetContainer extends BaseWidgetContainer
{
	private $db;			// DB接続オブジェクト
	private $outputText;	// 作成したメニュー
	private $templateType;		// テンプレートのタイプ
	const MAIN_MENU_ID = 'main_menu';			// メインメニューID
	const LOGIN_MENU_ID = 'main_login_user';		// ログインユーザ向けのメインメニューID
	const DEFAULT_TITLE = 'メインメニュー';	// デフォルトのタイトル
	
	/**
	 * コンストラクタ
	 */
	function __construct()
	{
		// 親クラスを呼び出す
		parent::__construct();
		
		// DBオブジェクト作成
		$this->db = new default_mainmenuDb();
	}
	/**
	 * テンプレートファイルを設定
	 *
	 * _assign()でデータを埋め込むテンプレートファイルのファイル名を返す。
	 * 読み込むディレクトリは、「自ウィジェットディレクトリ/include/template」に固定。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。そのまま_assign()に渡る
	 * @return string 						テンプレートファイル名。テンプレートライブラリを使用しない場合は空文字列「''」を返す。
	 */
	function _setTemplate($request, &$param)
	{
		// メニュー情報を取得
		// ログインメニューを表示するときでも、タイトルはメインメニューのタイトルを使用する
		$ret = $this->db->getMenu(self::MAIN_MENU_ID, $this->gEnv->getCurrentLanguage(), $row);
		if (!$ret){// 現在の言語で作成できない場合はデフォルト言語で作成
			$ret = $this->db->getMenu(self::MAIN_MENU_ID, $this->gEnv->getDefaultLanguage(), $row);
		}
		// Joomlaテンプレートのバージョンに合わせて出力
		$this->templateType = $this->gEnv->getCurrentTemplateType();
		if ($this->templateType == 0){			// Joomla!v1.0のとき
			return 'index_old.tmpl.html';
		} else {
			return 'index.tmpl.html';
		}
	}
	/**
	 * テンプレートにデータ埋め込む
	 *
	 * _setTemplate()で指定したテンプレートファイルにデータを埋め込む。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。_setTemplate()と共有。
	 * @param								なし
	 */
	function _assign($request, &$param)
	{
		// ユーザのログイン状況から表示するメニューのタイプを決定する
		$menuType = self::MAIN_MENU_ID;
		if ($this->gEnv->isCurrentUserLogined()){		// ログイン中のとき
			// メニューデータが存在するかどうかチェック
			if ($this->db->isExistsMenuItems(self::LOGIN_MENU_ID)) $menuType = self::LOGIN_MENU_ID;
		}
		
		// メインメニューの項目取得
		// 現在の言語で作成
		$this->db->getMenuItems(array($this, 'itemsLoop'), $menuType, $this->gEnv->getCurrentLanguage());
		if ($this->outputText == ''){// 現在の言語で作成できない場合はデフォルト言語で作成
			$this->db->getMenuItems(array($this, 'itemsLoop'), $menuType, $this->gEnv->getDefaultLanguage());
		}
	}
	/**
	 * ウィジェットのタイトルを設定
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。そのまま_assign()に渡る
	 * @return string 						ウィジェットのタイトル名
	 */
	function _setTitle($request, &$param)
	{
		return self::DEFAULT_TITLE;
	}
	/**
	 * 取得したメニュー項目をテンプレートに設定する
	 *
	 * @param int		$index			行番号
	 * @param array		$fetchedRow		取得行
	 * @param object	$param			任意使用パラメータ
	 * @return bool						trueを返すとループ続行。falseを返すとその時点で終了。
	 */
	function itemsLoop($index, $fetchedRow)
	{
		$classArray = array();
		
		// Joomla1.0対応
		if ($this->templateType == 0) $classArray[] = 'mainlevel';
				
		// リンクタイプに合わせてタグを生成
		$option = '';
		if (count($classArray) > 0) $option .= 'class="' . implode(' ', $classArray) . '"';
		switch ($fetchedRow['mi_link_type']){
			case 0:			// 同ウィンドウで開くリンク
				break;
			case 1:			// 別ウィンドウで開くリンク
				$option = ' target="_blank"';
				break;
		}
		
		// 「mainlevel」「sublevel」「active_menu」クラス名を設定する
		$name = '';
		if ($fetchedRow['mi_show_name']){	// 名前を表示するとき
			$name = $fetchedRow['mi_name'];
		}
		// リンク先の作成
		$linkUrl = '';
		if ($fetchedRow['mi_enable']){		// 遷移可能なとき
			$linkUrl = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $this->gEnv->getRootUrl(), $fetchedRow['mi_link_url']);
		} else {
			$linkUrl = '#';
		}
		
		if (!empty($name)){
			$row = array(
				'link_url' => $this->convertUrlToHtmlEntity($linkUrl),		// リンク
				'name' => $this->convertToDispString($name),			// タイトル
				'option' => $option			// Aタグ追加属性
			);
			$this->tmpl->addVars('itemlist', $row);
			$this->tmpl->parseTemplate('itemlist', 'a');
		
			$this->outputText .= $fetchedRow['mi_name'];
		}
		return true;
	}
}
?>
