<?php
/**
 * includeプラグイン
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2008 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: include.inc.php 1115 2008-10-24 06:38:06Z fishbone $
 * @link       http://www.magic3.org
 */
//--------
//	| PageA
//	|
//	| // #include(PageB)
//	---------
//		| PageB
//		|
//		| // #include(PageC)
//		---------
//			| PageC
//			|
//		--------- // PageC end
//		|
//		| // #include(PageD)
//		---------
//			| PageD
//			|
//		--------- // PageD end
//		|
//	--------- // PageB end
//	|
//	| #include(): Included already: PageC
//	|
//	| // #include(PageE)
//	---------
//		| PageE
//		|
//	--------- // PageE end
//	|
//	| #include(): Limit exceeded: PageF
//	| // When PLUGIN_INCLUDE_MAX == 4
//	|
//	|
//-------- // PageA end

// Default value of 'title|notitle' option
define('PLUGIN_INCLUDE_WITH_TITLE', TRUE);	// Default: TRUE(title)

// Max pages allowed to be included at a time
define('PLUGIN_INCLUDE_MAX', 4);

// ----
define('PLUGIN_INCLUDE_USAGE', '#include(): Usage: (a-page-name-you-want-to-include[,title|,notitle])');

function plugin_include_convert()
{
	//global $script, $vars, $get, $post, $menubar, $_msg_include_restrict;
	global $script, $_msg_include_restrict;
	static $included = array();
	static $count = 1;

	if (func_num_args() == 0) return PLUGIN_INCLUDE_USAGE . '<br />' . "\n";;

	// $menubar will already be shown via menu plugin
	$menubar = WikiConfig::getMenuBarPage();
	if (! isset($included[$menubar])) $included[$menubar] = TRUE;
	
	// Loop yourself
	//$root = isset($vars['page']) ? $vars['page'] : '';
	$root = WikiParam::getPage();
	$included[$root] = TRUE;

	// Get arguments
	$args = func_get_args();
	// strip_bracket() is not necessary but compatible
	$page = isset($args[0]) ? get_fullname(strip_bracket(array_shift($args)), $root) : '';
	$with_title = PLUGIN_INCLUDE_WITH_TITLE;
	if (isset($args[0])) {
		switch(strtolower(array_shift($args))) {
		case 'title'  : $with_title = TRUE;  break;
		case 'notitle': $with_title = FALSE; break;
		}
	}

	$s_page = htmlspecialchars($page);
	$r_page = rawurlencode($page);
	$link = '<a href="' . WikiParam::convQuery($script . '?' . $r_page) . '">' . $s_page . '</a>'; // Read link

	// I'm stuffed
	if (isset($included[$page])) {
		return '#include(): Included already: ' . $link . '<br />' . "\n";
	} if (! is_page($page)) {
		return '#include(): No such page: ' . $s_page . '<br />' . "\n";
	} if ($count > PLUGIN_INCLUDE_MAX) {
		return '#include(): Limit exceeded: ' . $link . '<br />' . "\n";
	} else {
		++$count;
	}

	// One page, only one time, at a time
	$included[$page] = TRUE;

	// Include A page, that probably includes another pages
	//$get['page'] = $post['page'] = $vars['page'] = $page;
	WikiParam::setPage($page);
	if (check_readable($page, false, false)) {
		$body = convert_html(get_source($page));
	} else {
		$body = str_replace('$1', $page, $_msg_include_restrict);
	}
	//$get['page'] = $post['page'] = $vars['page'] = $root;
	WikiParam::setPage($root);

	// Put a title-with-edit-link, before including document
	if ($with_title) {
		$link = '<a href="' . $script . WikiParam::convQuery('?cmd=edit&amp;page=' . $r_page) . '">' . $s_page . '</a>';
		if ($page == $menubar) {
			$body = '<span align="center"><h5 class="side_label">' . $link . '</h5></span><small>' . $body . '</small>';
		} else {
			$body = '<h1>' . $link . '</h1>' . "\n" . $body . "\n";
		}
	}
	return $body;
}
?>
